#
# spec file for package python-pkginfo
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pkginfo
Version:        1.5.0.1
Release:        lp152.2.3.1
Summary:        Python package for querying metadatdata from sdists/bdists/installed packages
License:        MIT
Group:          Development/Languages/Python
URL:            http://pypi.python.org/pypi/pkginfo/
Source:         https://files.pythonhosted.org/packages/source/p/pkginfo/pkginfo-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(preun): update-alternatives
Requires:       python-setuptools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This package provides an API for querying the distutils metadata written in
the PKG-INFO file inside a source distriubtion (an sdist) or a
binary distribution (e.g., created by running bdist_egg).  It can
also query the EGG-INFO directory of an installed distribution, and
the *.egg-info stored in a "development checkout"
(e.g, created by running setup.py develop).

%prep
%setup -q -n pkginfo-%{version}
# fix tests until fixed upstream
sed -i "s|'2\.1'|None|" pkginfo/tests/test_installed.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pkginfo

%check
%pytest

%post
%python_install_alternative pkginfo

%preun
%python_uninstall_alternative pkginfo

%files %{python_files}
%license LICENSE.txt
%doc README.txt CHANGES.txt TODO.txt
%python_alternative %{_bindir}/pkginfo
%{python_sitelib}/pkginfo
%{python_sitelib}/pkginfo-%{version}-py*.egg-info

%changelog
* Mon Dec 14 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Wed Jun 19 2019 pgajdos@suse.com
- version update to 1.5.0.1
  * Fix broken 'sdist'. LP #1639585.
  * Fix 'console_scripts' entry point syntax. LP #1810734.
  * Add support for JSON output from the CLI.
  * Add support for installed wheels.  E.g., 'dist-info/' dirs.
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun May 20 2018 hpj@urpla.net
- fix failing tests with sed
- enable tests
* Sat May 19 2018 hpj@urpla.net
- Update to version 1.4.2
  - Use relative imports in pkginfo modules.  Supports vendoring of the
    package into setuptools.
  - Add support for ``Provides-Extra`` and ``Description-Content-Type`` fields.
    Per https://packaging.python.org/specifications/.  See:  PEP 566.
  - Remove support for old setuptools leaving ``PKG-INFO`` in the root of
    the project directory.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to version 1.4.1
  * Packaging only change (invalid sdist bulit for 1.4.0).
- Update to version 1.4.0
  * Relicense under MIT license: the PSF license is not suitable for third-party libraries.
- Update to version 1.3.2
  * Packaging-only change (automate fix for wheel built for 1.3.1).
- Update to version 1.3.1
  * Packaging-only change (invalid wheel built for 1.3.0).
- Update to version 1.3.0
  * Update homepage URL to point to Launchpad, rather than PyPI.
  * Add support for building wheels.
  * Add support for Python 3.5.
  * Drop support for Python 2.6 and 3.2.
- Implement single-spec version.
* Tue Jun  2 2015 p.drouand@gmail.com
- Update to version 1.2.1
  * Add overlooked Trove classifier for Python 3.4.
- Changes from version 1.2 final
  * Add support for Python 3.4, PyPy3.
  * Add 100%% coverage for pkginfo.commandline module.
* Tue Feb  4 2014 speilicke@suse.com
- Initial version
